Learn R Programming

bpnreg (version 1.0.3)

pnr: A Gibbs sampler for a projected normal regression model

Description

A Gibbs sampler for a projected normal regression model

Usage

pnr(theta, X1r, X2r, its, lag, burn)

Arguments

theta

A vector with the circular dependent variable.

X1r

A model matrix for component I.

X2r

A model matrix for component II.

its

An integer specifying the number of iterations

lag

An integer specifying the amount of lag.

burn

An integer specifying the number of burn-in iterations.