Learn R Programming

bpnreg (version 1.0.3)

predict.bpnr: Predicted values for a Bayesian circular regression model

Description

Outputs predicted values for a Bayesian circular regression model for each iteration of the MCMC sampler.

Usage

# S3 method for bpnr
predict(object, ...)

Arguments

object

a bpnr object obtained from the function bpnr.

...

further arguments passed to or from other methods.

Value

a matrix (rows = N, columns = iterations) containing predicted values for the circular outcome for each iteration of the MCMC sampler.

Examples

Run this code
# NOT RUN {
library(bpnreg)
fit.Motor <- bpnr(pred.I = Phaserad ~ 1 + Cond, data = Motor,
its = 100, burn = 10, n.lag = 3)
predict(fit.Motor)

# }

Run the code above in your browser using DataLab