one of c("B1", "B2", Beta.I", "Beta.II", a.x", "a.c",
"b.c", "SAM", "AS", "SSDO", "circ.diff", "VCovI", "VCovII", "cRI", "cRS")
to indicate for which parameter a traceplot is required. B1,
Beta.I, B2 and Beta.II are the linear intercepts and
coefficients of the first and second component for a regression model and
the fixed effects coefficients of a mixed-effects model. circ.diff
are the circular differences with the intercept on the outcome variable for
the different levels of categorical variables. VCovI and
VCovII are the linear random effect variances and cRI and
cRS are the variances of the circular random intercept and circular
random slope.