powered by
Outputs predicted values for a Bayesian circular regression model for each iteration of the MCMC sampler.
# S3 method for bpnr predict(object, ...)
a bpnr object obtained from the function bpnr.
bpnr object
bpnr
further arguments passed to or from other methods.
a matrix (rows = N, columns = iterations) containing predicted values for the circular outcome for each iteration of the MCMC sampler.
# NOT RUN { library(bpnreg) fit.Motor <- bpnr(pred.I = Phaserad ~ 1 + Cond, data = Motor, its = 100, burn = 10, n.lag = 3) predict(fit.Motor) # }
Run the code above in your browser using DataLab